==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/scripts/route_tester.sh <==
#!/usr/bin/env sh
set -x
# Generates a route based on the Mobility DB's spec'd bbox for two random
# points within the bbox. Sets arbitrarily high walk/transfer seconds params.
# Can be used as a coarse testing mechanism to make sure routing for a given
# source is feasible / working in the system.

rnd() {
  LOWER=$1
  UPPER=$2
  INTERVAL=$3

  INTERVALSIGN="$(awk 'BEGIN { print ('$LOWER' >= '$UPPER') ? "-" : "+" }')"
  seq $LOWER ${INTERVALSIGN}${INTERVAL} $UPPER | shuf | head -n1
}

genreq() {
  FEEDID=$1
  FROMLAT=$2
  FROMLON=$3
  TOLAT=$4
  TOLON=$5
  echo '{
    "route_params": {
      "feed_ids": ['$FEEDID'],
      "from": ['$FROMLAT', '$FROMLON'],
      "to": ['$TOLAT', '$TOLON'],
      "max_walk_seconds": 99999999999999,
      "transfer_categories": ["f", "i"],
      "output_formats": ["legs", "diagnostics", "mapurl", "request"],
      "max_transfer_seconds": 600
    }
  }'
}

route() {
  FEEDID="$1"

  ./build.sh || exit 1

  echo "$FEEDID" | grep '[0-9]+'
  BBOX="$(
    ./mobroute databaseq -p '{"databaseq_params": {"feed_ids": ['"$FEEDID"']}}' | jq '.[0].bbox' | grep -oE '[0-9,.-]+' | tr -d "\n"
  )"

  LATA="$(echo $BBOX | cut -d, -f1)"
  LONA="$(echo $BBOX | cut -d, -f2)"
  LATB="$(echo $BBOX | cut -d, -f3)"
  LONB="$(echo $BBOX | cut -d, -f4)"

  INTERVAL=0.01
  FROMLAT="$(rnd $LATA $LATB $INTERVAL)"
  FROMLON="$(rnd $LONA $LONB $INTERVAL)"

  TOLAT="$(rnd $LATA $LATB $INTERVAL)"
  TOLON="$(rnd $LONA $LONB $INTERVAL)"

  ./mobroute route -p "$(genreq $FEEDID $FROMLAT $FROMLON $TOLAT $TOLON)"
}

if [ "$#" -eq 1 ]; then
  route $1
else
  echo "Pass first argument as FEEDID"
fi

==> mobroute-0.9.0.tar.gz: mobroute-v0.9.0/scripts/route_tester.sh <==
#!/usr/bin/env sh
set -x
# Generates a route based on the Mobility DB's spec'd bbox for two random
# points within the bbox. Sets arbitrarily high walk/transfer seconds params.
# Can be used as a coarse testing mechanism to make sure routing for a given
# source is feasible / working in the system.

rnd() {
  LOWER=$1
  UPPER=$2
  INTERVAL=$3

  INTERVALSIGN="$(awk 'BEGIN { print ('$LOWER' >= '$UPPER') ? "-" : "+" }')"
  seq $LOWER ${INTERVALSIGN}${INTERVAL} $UPPER | shuf | head -n1
}

genreq() {
  FEEDID=$1
  FROMLAT=$2
  FROMLON=$3
  TOLAT=$4
  TOLON=$5
  echo '{
    "feed_ids": ['$FEEDID'],
    "from": ['$FROMLAT', '$FROMLON'],
    "to": ['$TOLAT', '$TOLON'],
    "max_walk_seconds": 99999999999999,
    "transfer_categories": ["f", "i"],
    "output_formats": ["legs", "diagnostics", "mapurl", "request"],
    "max_transfer_seconds": 600
  }'
}

route() {
  FEEDID="$1"

  ./build.sh || exit 1

  echo "$FEEDID" | grep '[0-9]+'
  BBOX="$(
    ./mobroute databaseq -p '{"feed_ids": ['"$FEEDID"']}' | jq '.[0].bbox' | grep -oE '[0-9,.-]+' | tr -d "\n"
  )"

  LATA="$(echo $BBOX | cut -d, -f1)"
  LONA="$(echo $BBOX | cut -d, -f2)"
  LATB="$(echo $BBOX | cut -d, -f3)"
  LONB="$(echo $BBOX | cut -d, -f4)"

  INTERVAL=0.01
  FROMLAT="$(rnd $LATA $LATB $INTERVAL)"
  FROMLON="$(rnd $LONA $LONB $INTERVAL)"

  TOLAT="$(rnd $LATA $LATB $INTERVAL)"
  TOLON="$(rnd $LONA $LONB $INTERVAL)"

  ./mobroute database -p '{"op": "loadmdbgtfs", "feed_ids": ['$FEEDID'], "loadmdbgtfs_update": true, "loadmdbgtfs_direct_urls": true}'
  ./mobroute database -p '{"op": "compute", "feed_ids": ['$FEEDID']}'
  ./mobroute route -p "$(genreq $FEEDID $FROMLAT $FROMLON $TOLAT $TOLON)"
}

if [ "$#" -eq 1 ]; then
  route $1
else
  echo "Pass first argument as FEEDID"
fi
